MCD triple_NNN
Appliquer ( employé, projet, compétence )

- Le champ employé fait partie de la clé primaire de la table. Sa table d'origine (Employé) ayant été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ projet fait partie de la clé primaire de la table. Sa table d'origine (Projet) ayant été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ compétence fait partie de la clé primaire de la table. Sa table d'origine (Compétence) ayant été supprimée, il n'est pas considéré comme clé étrangère.

NB. Les tables Compétence, Employé et Projet ont été supprimées car elles étaient réduites à la clé primaire de leur entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.